QUlo requires

* Python-3.6.x
* psutil (``pip install psutil``)

To install the program::

  $ pip install QULo-1.7.4.tar.gz

Before running the program, a configuration file is needed. One example is provided::

  doc/qagent.conf

As it is now, run the program like this ::

  $ cp doc/qagent.conf /tmp
  $ qmaster start
  $ qagent start

  
